@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-# Copyright 2013-2020 by Björn Johansson.  All rights reserved.
+# Copyright 2013-2023 by Björn Johansson.  All rights reserved.
 # This code is part of the Python-dna distribution and governed by its
 # license.  Please see the LICENSE.txt file that should have been included
 # as part of this package.
@@ -42,7 +42,7 @@ def read(data, ds=True):
     try:
         results = results.pop()
     except IndexError:
-        raise ValueError("No sequences found in data:\n({})".format(data[:79]))
+        raise ValueError(f"No sequences found in data:\n({str(data)[:79]})")
     return results
 
 
